#include "UnoJoy.h"

// Define our pins
int TrianglePin = 4;
int SquarePin = 5;
int CrossPin = 3;
int CirclePin = 2;

int LeftPin = 8;
int UpPin = 9;
int RightPin = 10;
int DownPin = 11;

int StartPin = 12;

// Additional buttons
int l1Pin = 6;
int l2Pin = 7; // l2 as pin 7
int selectPin = 13; // Select button on pin 13
// int r1Pin = A0;
// int r2Pin = A1;

void setup() {
  setupPins();
  setupUnoJoy();

  // Initialize serial communication
  Serial.begin(9600);
}

void loop() {
  // Always be getting fresh data
  dataForController_t controllerData = getControllerData();

  // Print button input state to Serial Monitor
  if (controllerData.triangleOn) {
    Serial.println("Triangle button is pressed.");
  }
  if (controllerData.circleOn) {
    Serial.println("Circle button is pressed.");
  }
  if (controllerData.squareOn) {
    Serial.println("Square button is pressed.");
  }
  if (controllerData.crossOn) {
    Serial.println("Cross button is pressed.");
  }
  if (controllerData.startOn) {
    Serial.println("Start button is pressed.");
  }

  // Print directional input state to Serial Monitor
  if (controllerData.dpadUpOn) {
    Serial.println("UP input is active.");
  }
  if (controllerData.dpadDownOn) {
    Serial.println("DOWN input is active.");
  }
  if (controllerData.dpadLeftOn) {
    Serial.println("LEFT input is active.");
  }
  if (controllerData.dpadRightOn) {
    Serial.println("RIGHT input is active.");
  }

  // Additional buttons
  if (controllerData.l1On) {
    Serial.println("L1 button is pressed.");
  }
  if (controllerData.l2On) {
    Serial.println("L2 button is pressed.");
  }
  if (controllerData.r1On) {
    Serial.println("R1 button is pressed.");
  }
  if (controllerData.r2On) {
    Serial.println("R2 button is pressed.");
  }
  if(controllerData.selectOn) {
    Serial.println("Select button is pressed.");
  }

  // Set controller data
  setControllerData(controllerData);
}

void setupPins(void) {
  // Set all the digital pins as inputs
  // with the pull-up enabled, except for the
  // two serial line pins
  for (int i = 2; i <= 12; i++) {
    pinMode(i, INPUT_PULLUP);
    digitalWrite(i, HIGH);
  }
}

dataForController_t getControllerData(void) {
  // Set up a place for our controller data
  dataForController_t controllerData = getBlankDataForController();

  // Read button inputs
  controllerData.triangleOn = !digitalRead(TrianglePin);
  controllerData.circleOn = !digitalRead(CirclePin);
  controllerData.squareOn = !digitalRead(SquarePin);
  controllerData.crossOn = !digitalRead(CrossPin);
  controllerData.startOn = !digitalRead(StartPin);

  // Read directional inputs
  controllerData.dpadUpOn = !digitalRead(UpPin);
  controllerData.dpadDownOn = !digitalRead(DownPin);
  controllerData.dpadLeftOn = !digitalRead(LeftPin);
  controllerData.dpadRightOn = !digitalRead(RightPin);

  // Additional buttons
  controllerData.l1On = !digitalRead(l1Pin);
  controllerData.l2On = !digitalRead(l2Pin);
  controllerData.selectOn = !digitalRead(selectPin);


  // controllerData.r1On = !digitalRead(r1Pin);
  // controllerData.r2On = !digitalRead(r2Pin);

  // Return the data
  return controllerData;
}
